Speasy examples gallery
=======================

Browse example folder on MyBinder:

.. image:: https://mybinder.org/badge_logo.svg
 :target: https://mybinder.org/v2/gh/SciQLop/speasy/main?labpath=docs/examples

.. nbgallery::
   :glob:

   ./AMDA
   ./SSCWeb
   ./Caches
